==> rc-ui-lib-0.1.35.tgz: package/es/steps/StepsItem.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children"];
import React, { useContext, useMemo } from 'react';
import cls from 'classnames';
import { BORDER } from '../utils/constant';
import Icon from '../icon';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var StepsItem = function StepsItem(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, _excluded);

  var index = props.index,
      parentProps = props.parent;

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('step', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  if (!parentProps) {
    if (process.env.NODE_ENV !== 'production') {
      // eslint-disable-next-line no-console
      console.error('[rc-ui-lib] <Step> must be a child component of <Steps>.');
    }
  }

  var getStatus = function getStatus() {
    var active = +parentProps.active;

    if (index < active) {
      return 'finish';
    }

    return index === active ? 'process' : 'waiting';
  };

  var isActive = function isActive() {
    return getStatus() === 'process';
  };

  var lineStyle = useMemo(function () {
    return {
      background: getStatus() === 'finish' ? parentProps.activeColor : parentProps.inactiveColor
    };
  }, [index, parentProps.active, parentProps.activeColor, parentProps.inactiveColor]);
  var titleStyle = useMemo(function () {
    if (isActive()) {
      return {
        color: parentProps.activeColor
      };
    }

    if (!getStatus()) {
      return {
        color: parentProps.inactiveColor
      };
    }

    return {};
  }, [index, parentProps.active, parentProps.activeColor, parentProps.inactiveColor]);

  var onClickStep = function onClickStep() {
    if (parentProps.onClickStep) parentProps.onClickStep(index);
  };

  var renderCircle = function renderCircle() {
    var iconPrefix = parentProps.iconPrefix,
        finishIcon = parentProps.finishIcon,
        activeIcon = parentProps.activeIcon,
        activeColor = parentProps.activeColor,
        inactiveIcon = parentProps.inactiveIcon;

    if (isActive()) {
      if ( /*#__PURE__*/React.isValidElement(parentProps.activeIcon)) {
        return parentProps.activeIcon;
      }

      return /*#__PURE__*/React.createElement(Icon, {
        className: cls(bem('icon', 'active')),
        name: activeIcon,
        color: activeColor,
        classPrefix: iconPrefix
      });
    }

    if (getStatus() === 'finish' && (finishIcon || /*#__PURE__*/React.isValidElement(parentProps.finishIcon))) {
      if ( /*#__PURE__*/React.isValidElement(parentProps.finishIcon)) {
        return parentProps.finishIcon;
      }

      return /*#__PURE__*/React.createElement(Icon, {
        className: cls(bem('icon', 'finish')),
        name: finishIcon,
        color: activeColor,
        classPrefix: iconPrefix
      });
    }

    if ( /*#__PURE__*/React.isValidElement(parentProps.inactiveIcon)) {
      return parentProps.inactiveIcon;
    }

    if (inactiveIcon) {
      return /*#__PURE__*/React.createElement(Icon, {
        className: cls(bem('icon')),
        name: inactiveIcon,
        classPrefix: iconPrefix
      });
    }

    return /*#__PURE__*/React.createElement("i", {
      className: cls(bem('circle')),
      style: lineStyle
    });
  };

  var status = getStatus();
  return /*#__PURE__*/React.createElement("div", {
    style: props.style,
    className: cls(props.className, BORDER, bem([parentProps.direction, _defineProperty({}, status, status)]))
  }, /*#__PURE__*/React.createElement("div", {
    className: cls(bem('title', {
      active: isActive()
    })),
    style: titleStyle,
    onClick: onClickStep
  }, children), /*#__PURE__*/React.createElement("div", {
    className: cls(bem('circle-container')),
    onClick: onClickStep
  }, renderCircle()), /*#__PURE__*/React.createElement("div", {
    className: cls(bem('line')),
    style: lineStyle
  }));
};

export default StepsItem;

==> rc-ui-lib-0.2.4.tgz: package/es/steps/StepsItem.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children"];
import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { BORDER } from '../utils/constant';
import Icon from '../icon';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var StepsItem = function StepsItem(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, _excluded);

  var index = props.index,
      parentProps = props.parent;

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('step', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  if (!parentProps) {
    if (process.env.NODE_ENV !== 'production') {
      // eslint-disable-next-line no-console
      console.error('[rc-ui-lib] <Step> must be a child component of <Steps>.');
    }
  }

  var getStatus = function getStatus() {
    var active = +parentProps.active;

    if (index < active) {
      return 'finish';
    }

    return index === active ? 'process' : 'waiting';
  };

  var isActive = function isActive() {
    return getStatus() === 'process';
  };

  var lineStyle = useMemo(function () {
    return {
      background: getStatus() === 'finish' ? parentProps.activeColor : parentProps.inactiveColor
    };
  }, [index, parentProps.active, parentProps.activeColor, parentProps.inactiveColor]);
  var titleStyle = useMemo(function () {
    if (isActive()) {
      return {
        color: parentProps.activeColor
      };
    }

    if (!getStatus()) {
      return {
        color: parentProps.inactiveColor
      };
    }

    return {};
  }, [index, parentProps.active, parentProps.activeColor, parentProps.inactiveColor]);

  var onClickStep = function onClickStep() {
    if (parentProps.onClickStep) parentProps.onClickStep(index);
  };

  var renderCircle = function renderCircle() {
    var iconPrefix = parentProps.iconPrefix,
        finishIcon = parentProps.finishIcon,
        activeIcon = parentProps.activeIcon,
        activeColor = parentProps.activeColor,
        inactiveIcon = parentProps.inactiveIcon;

    if (isActive()) {
      if ( /*#__PURE__*/React.isValidElement(parentProps.activeIcon)) {
        return parentProps.activeIcon;
      }

      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(bem('icon', 'active')),
        name: activeIcon,
        color: activeColor,
        classPrefix: iconPrefix
      });
    }

    if (getStatus() === 'finish' && (finishIcon || /*#__PURE__*/React.isValidElement(parentProps.finishIcon))) {
      if ( /*#__PURE__*/React.isValidElement(parentProps.finishIcon)) {
        return parentProps.finishIcon;
      }

      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(bem('icon', 'finish')),
        name: finishIcon,
        color: activeColor,
        classPrefix: iconPrefix
      });
    }

    if ( /*#__PURE__*/React.isValidElement(parentProps.inactiveIcon)) {
      return parentProps.inactiveIcon;
    }

    if (inactiveIcon) {
      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(bem('icon')),
        name: inactiveIcon,
        classPrefix: iconPrefix
      });
    }

    return /*#__PURE__*/React.createElement("i", {
      className: classnames(bem('circle')),
      style: lineStyle
    });
  };

  var status = getStatus();
  return /*#__PURE__*/React.createElement("div", {
    style: props.style,
    className: classnames(props.className, BORDER, bem([parentProps.direction, _defineProperty({}, status, status)]))
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('title', {
      active: isActive()
    })),
    style: titleStyle,
    onClick: onClickStep
  }, children), /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('circle-container')),
    onClick: onClickStep
  }, renderCircle()), /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('line')),
    style: lineStyle
  }));
};

export default StepsItem;
